Changelog
=========

0.1.0
-----

- Provide all in one configure file

0.0.8
-----

- Include template files

0.0.7
-----

- Include jinja2 templates

0.0.6
-----

- Add json error page configuration file

0.0.5
-----

- Add coverage

0.0.4
-----

- Clear dependency

0.0.3
-----

- Dumps nginx to files

0.0.2
-----

- Render conf with template

0.0.1
-----

- Initial public release
